# Hello World

An example project which demonstrates how to publish a python module to PyPI.

## Installation

Run the following to install

```python
pip install helloworld_clippersys
```

## Usage

```python
from helloworld_clippersys import helloworld
# print "Hello World!"
helloworld()
```
## Developing Hello World

```bash
pip install -e .[dev]
```
